@@ -1,5 +1,4 @@
 import unittest
-import weakref
 
 from scrapy.http import Request, Response, TextResponse, HtmlResponse, XmlResponse, Headers
 from scrapy.utils.encoding import resolve_encoding
@@ -92,13 +91,6 @@ class BaseResponseTest(unittest.TestCase):
         self.assertEqual(r4.body, '')
         self.assertEqual(r4.flags, [])
 
-    def test_weakref_slots(self):
-        """Check that classes are using slots and are weak-referenceable"""
-        x = self.response_class('http://www.example.com')
-        weakref.ref(x)
-        assert not hasattr(x, '__dict__'), "%s does not use __slots__" % \
-            x.__class__.__name__
-
     def _assert_response_values(self, response, encoding, body):
         if isinstance(body, unicode):
             body_unicode = body
@@ -260,6 +252,10 @@ class HtmlResponseTest(TextResponseTest):
         r4 = r3.replace(body=body)
         self._assert_response_values(r4, 'iso-8859-1', body)
 
+    def test_html5_meta_charset(self):
+        body = """<html><head><meta charset="gb2312" /><title>Some page</title><body>bla bla</body>"""
+        r1 = self.response_class("http://www.example.com", body=body)
+        self._assert_response_values(r1, 'gb2312', body)
 
 
 class XmlResponseTest(TextResponseTest):
